@@ -46,6 +46,7 @@ from .type_defs import (
     DescribeJobsResponseTypeDef,
     JobDependencyTypeDef,
     JobTimeoutTypeDef,
+    KeyValuesPairTypeDef,
     ListJobsResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
     NodeOverridesTypeDef,
@@ -82,7 +83,7 @@ class Exceptions:
 
 class BatchClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html)
     """
 
@@ -98,15 +99,15 @@ class BatchClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#can_paginate)
         """
 
     def cancel_job(self, *, jobId: str, reason: str) -> Dict[str, Any]:
         """
-        Cancels a job in an AWS Batch job queue.
+        Cancels a job in an Batch job queue.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.cancel_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.cancel_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#cancel_job)
         """
 
@@ -121,9 +122,9 @@ class BatchClient(BaseClient):
         tags: Dict[str, str] = None
     ) -> CreateComputeEnvironmentResponseTypeDef:
         """
-        Creates an AWS Batch compute environment.
+        Creates an Batch compute environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.create_compute_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.create_compute_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#create_compute_environment)
         """
 
@@ -137,17 +138,17 @@ class BatchClient(BaseClient):
         tags: Dict[str, str] = None
     ) -> CreateJobQueueResponseTypeDef:
         """
-        Creates an AWS Batch job queue.
+        Creates an Batch job queue.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.create_job_queue)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.create_job_queue)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#create_job_queue)
         """
 
     def delete_compute_environment(self, *, computeEnvironment: str) -> Dict[str, Any]:
         """
-        Deletes an AWS Batch compute environment.
+        Deletes an Batch compute environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.delete_compute_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.delete_compute_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#delete_compute_environment)
         """
 
@@ -155,15 +156,15 @@ class BatchClient(BaseClient):
         """
         Deletes the specified job queue.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.delete_job_queue)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.delete_job_queue)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#delete_job_queue)
         """
 
     def deregister_job_definition(self, *, jobDefinition: str) -> Dict[str, Any]:
         """
-        Deregisters an AWS Batch job definition.
+        Deregisters an Batch job definition.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.deregister_job_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.deregister_job_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#deregister_job_definition)
         """
 
@@ -177,7 +178,7 @@ class BatchClient(BaseClient):
         """
         Describes one or more of your compute environments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.describe_compute_environments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.describe_compute_environments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_compute_environments)
         """
 
@@ -193,7 +194,7 @@ class BatchClient(BaseClient):
         """
         Describes a list of job definitions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.describe_job_definitions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.describe_job_definitions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_job_definitions)
         """
 
@@ -203,7 +204,7 @@ class BatchClient(BaseClient):
         """
         Describes one or more of your job queues.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.describe_job_queues)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.describe_job_queues)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_job_queues)
         """
 
@@ -211,7 +212,7 @@ class BatchClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.describe_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.describe_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_jobs)
         """
 
@@ -225,7 +226,7 @@ class BatchClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#generate_presigned_url)
         """
 
@@ -237,20 +238,21 @@ class BatchClient(BaseClient):
         multiNodeJobId: str = None,
         jobStatus: JobStatusType = None,
         maxResults: int = None,
-        nextToken: str = None
+        nextToken: str = None,
+        filters: List["KeyValuesPairTypeDef"] = None
     ) -> ListJobsResponseTypeDef:
         """
-        Returns a list of AWS Batch jobs.
+        Returns a list of Batch jobs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.list_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.list_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#list_jobs)
         """
 
     def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        Lists the tags for an AWS Batch resource.
+        Lists the tags for an Batch resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#list_tags_for_resource)
         """
 
@@ -269,9 +271,9 @@ class BatchClient(BaseClient):
         platformCapabilities: List[PlatformCapabilityType] = None
     ) -> RegisterJobDefinitionResponseTypeDef:
         """
-        Registers an AWS Batch job definition.
+        Registers an Batch job definition.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.register_job_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.register_job_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#register_job_definition)
         """
 
@@ -292,9 +294,9 @@ class BatchClient(BaseClient):
         tags: Dict[str, str] = None
     ) -> SubmitJobResponseTypeDef:
         """
-        Submits an AWS Batch job from a job definition.
+        Submits an Batch job from a job definition.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.submit_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.submit_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#submit_job)
         """
 
@@ -302,7 +304,7 @@ class BatchClient(BaseClient):
         """
         Associates the specified tags to a resource with the specified `resourceArn`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#tag_resource)
         """
 
@@ -310,15 +312,15 @@ class BatchClient(BaseClient):
         """
         Terminates a job in a job queue.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.terminate_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.terminate_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#terminate_job)
         """
 
     def untag_resource(self, *, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        Deletes specified tags from an AWS Batch resource.
+        Deletes specified tags from an Batch resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#untag_resource)
         """
 
@@ -331,9 +333,9 @@ class BatchClient(BaseClient):
         serviceRole: str = None
     ) -> UpdateComputeEnvironmentResponseTypeDef:
         """
-        Updates an AWS Batch compute environment.
+        Updates an Batch compute environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.update_compute_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.update_compute_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#update_compute_environment)
         """
 
@@ -348,7 +350,7 @@ class BatchClient(BaseClient):
         """
         Updates a job queue.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Client.update_job_queue)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Client.update_job_queue)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#update_job_queue)
         """
 
@@ -357,7 +359,7 @@ class BatchClient(BaseClient):
         self, operation_name: Literal["describe_compute_environments"]
     ) -> DescribeComputeEnvironmentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Paginator.DescribeComputeEnvironments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Paginator.DescribeComputeEnvironments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#describecomputeenvironmentspaginator)
         """
 
@@ -366,7 +368,7 @@ class BatchClient(BaseClient):
         self, operation_name: Literal["describe_job_definitions"]
     ) -> DescribeJobDefinitionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Paginator.DescribeJobDefinitions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Paginator.DescribeJobDefinitions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#describejobdefinitionspaginator)
         """
 
@@ -375,13 +377,13 @@ class BatchClient(BaseClient):
         self, operation_name: Literal["describe_job_queues"]
     ) -> DescribeJobQueuesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Paginator.DescribeJobQueues)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Paginator.DescribeJobQueues)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#describejobqueuespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_jobs"]) -> ListJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/batch.html#Batch.Paginator.ListJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/batch.html#Batch.Paginator.ListJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#listjobspaginator)
         """
